## usethis namespace: start
#' @importFrom lifecycle deprecate_soft
## usethis namespace: end
NULL

#' @noRd
.pkgenv <- rlang::env()
